# $Id: getperlflags.pl 1014 2009-02-01 12:46:52Z ekalin $
# The ExtUtils::Embed module returns, under Windows, compiler options
# using the syntax used by Microsoft Compilers.
# Since I compile KildClient for Windows with mingw32, a port of gcc and
# related GNU applications, the flags must be using the gcc syntax.
# This file does the conversion

use ExtUtils::Embed;
use warnings;
use strict;

sub kcccopts {
  my $cflags = ccopts();

  print $cflags;
}


sub kcldopts {
  my $ldflags = ldopts();

  if ($^O eq 'MSWin32') {
    $ldflags =~ s#\\#/#g;
  }

  print $ldflags;
}


if ($ARGV[0] eq 'ccopts') {
  kcccopts();
} elsif ($ARGV[0] eq 'ldopts') {
  kcldopts();
}
